@@ -33,7 +33,7 @@ class AutoSnapshotPolicyInfo(AbstractModel):
         :type CreationTime: str
         :param FileSystemNums: 关联的文件系统个数
         :type FileSystemNums: int
-        :param DayOfWeek: 快照定期备份在一星期哪一天
+        :param DayOfWeek: 快照定期备份在一星期哪一天，该参数与DayOfMonth,IntervalDays互斥
         :type DayOfWeek: str
         :param Hour: 快照定期备份在一天的哪一小时
         :type Hour: str
@@ -51,6 +51,12 @@ class AutoSnapshotPolicyInfo(AbstractModel):
         :type RegionName: str
         :param FileSystems: 文件系统信息
         :type FileSystems: list of FileSystemByPolicy
+        :param DayOfMonth: 快照定期备份在一个月的某个时间；该参数与DayOfWeek,IntervalDays互斥
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DayOfMonth: str
+        :param IntervalDays: 快照定期间隔天数，1-365 天；该参数与DayOfMonth,DayOfWeek互斥
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntervalDays: int
         """
         self.AutoSnapshotPolicyId = None
         self.PolicyName = None
@@ -65,6 +71,8 @@ class AutoSnapshotPolicyInfo(AbstractModel):
         self.AliveDays = None
         self.RegionName = None
         self.FileSystems = None
+        self.DayOfMonth = None
+        self.IntervalDays = None
 
 
     def _deserialize(self, params):
@@ -86,6 +94,8 @@ class AutoSnapshotPolicyInfo(AbstractModel):
                 obj = FileSystemByPolicy()
                 obj._deserialize(item)
                 self.FileSystems.append(obj)
+        self.DayOfMonth = params.get("DayOfMonth")
+        self.IntervalDays = params.get("IntervalDays")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -306,26 +316,34 @@ class CreateAutoSnapshotPolicyRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DayOfWeek: 快照重复日期，星期一到星期日
-        :type DayOfWeek: str
         :param Hour: 快照重复时间点
         :type Hour: str
         :param PolicyName: 策略名称
         :type PolicyName: str
+        :param DayOfWeek: 快照重复日期，星期一到星期日
+        :type DayOfWeek: str
         :param AliveDays: 快照保留时长
         :type AliveDays: int
+        :param DayOfMonth: 快照按月重复，每月1-31号，选择一天，每月这一天打快照。
+        :type DayOfMonth: str
+        :param IntervalDays: 间隔天数
+        :type IntervalDays: int
         """
-        self.DayOfWeek = None
         self.Hour = None
         self.PolicyName = None
+        self.DayOfWeek = None
         self.AliveDays = None
+        self.DayOfMonth = None
+        self.IntervalDays = None
 
 
     def _deserialize(self, params):
-        self.DayOfWeek = params.get("DayOfWeek")
         self.Hour = params.get("Hour")
         self.PolicyName = params.get("PolicyName")
+        self.DayOfWeek = params.get("DayOfWeek")
         self.AliveDays = params.get("AliveDays")
+        self.DayOfMonth = params.get("DayOfMonth")
+        self.IntervalDays = params.get("IntervalDays")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1800,6 +1818,11 @@ class FileSystemInfo(AbstractModel):
         :type Capacity: int
         :param Tags: 文件系统标签列表
         :type Tags: list of TagInfo
+        :param TieringState: 文件系统声明周期管理状态
+        :type TieringState: str
+        :param TieringDetail: 分层存储详情
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TieringDetail: :class:`tencentcloud.cfs.v20190719.models.TieringDetailInfo`
         """
         self.CreationTime = None
         self.CreationToken = None
@@ -1821,6 +1844,8 @@ class FileSystemInfo(AbstractModel):
         self.BandwidthLimit = None
         self.Capacity = None
         self.Tags = None
+        self.TieringState = None
+        self.TieringDetail = None
 
 
     def _deserialize(self, params):
@@ -1851,6 +1876,10 @@ class FileSystemInfo(AbstractModel):
                 obj = TagInfo()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        self.TieringState = params.get("TieringState")
+        if params.get("TieringDetail") is not None:
+            self.TieringDetail = TieringDetailInfo()
+            self.TieringDetail._deserialize(params.get("TieringDetail"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2325,6 +2354,12 @@ class TagInfo(AbstractModel):
         
 
 
+class TieringDetailInfo(AbstractModel):
+    """分层存储详细信息
+
+    """
+
+
 class UnbindAutoSnapshotPolicyRequest(AbstractModel):
     """UnbindAutoSnapshotPolicy请求参数结构体
 
@@ -2393,6 +2428,10 @@ class UpdateAutoSnapshotPolicyRequest(AbstractModel):
         :type AliveDays: int
         :param IsActivated: 是否激活定期快照功能
         :type IsActivated: int
+        :param DayOfMonth: 定期快照在月的某几天天，该参数与DayOfWeek互斥
+        :type DayOfMonth: str
+        :param IntervalDays: 间隔天数定期执行快照，该参数与DayOfWeek,DayOfMonth 互斥
+        :type IntervalDays: int
         """
         self.AutoSnapshotPolicyId = None
         self.PolicyName = None
@@ -2400,6 +2439,8 @@ class UpdateAutoSnapshotPolicyRequest(AbstractModel):
         self.Hour = None
         self.AliveDays = None
         self.IsActivated = None
+        self.DayOfMonth = None
+        self.IntervalDays = None
 
 
     def _deserialize(self, params):
@@ -2409,6 +2450,8 @@ class UpdateAutoSnapshotPolicyRequest(AbstractModel):
         self.Hour = params.get("Hour")
         self.AliveDays = params.get("AliveDays")
         self.IsActivated = params.get("IsActivated")
+        self.DayOfMonth = params.get("DayOfMonth")
+        self.IntervalDays = params.get("IntervalDays")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2810,12 +2853,20 @@ class UserQuota(AbstractModel):
         :type FileHardLimit: int
         :param FileSystemId: 文件系统ID
         :type FileSystemId: str
+        :param CapacityUsed: 容量使用，单位GiB
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CapacityUsed: int
+        :param FileUsed: 文件使用个数，单位个
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FileUsed: int
         """
         self.UserType = None
         self.UserId = None
         self.CapacityHardLimit = None
         self.FileHardLimit = None
         self.FileSystemId = None
+        self.CapacityUsed = None
+        self.FileUsed = None
 
 
     def _deserialize(self, params):
@@ -2824,6 +2875,8 @@ class UserQuota(AbstractModel):
         self.CapacityHardLimit = params.get("CapacityHardLimit")
         self.FileHardLimit = params.get("FileHardLimit")
         self.FileSystemId = params.get("FileSystemId")
+        self.CapacityUsed = params.get("CapacityUsed")
+        self.FileUsed = params.get("FileUsed")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
